summaryrefslogtreecommitdiffstats
path: root/libkdepim/resourceabc.h
diff options
context:
space:
mode:
Diffstat (limited to 'libkdepim/resourceabc.h')
-rw-r--r--libkdepim/resourceabc.h28
1 files changed, 14 insertions, 14 deletions
diff --git a/libkdepim/resourceabc.h b/libkdepim/resourceabc.h
index dab79d0a..90abbf72 100644
--- a/libkdepim/resourceabc.h
+++ b/libkdepim/resourceabc.h
@@ -26,7 +26,7 @@
#define RESOURCEABC_H
#include <kabc/resource.h>
-#include <qmap.h>
+#include <tqmap.h>
#include <kdepimmacros.h>
// This is here because it can't go to kdelibs/kabc yet, but ultimately
@@ -55,58 +55,58 @@ public:
* The returned map has the UID as key and the resource it's in as
* the data.
*/
- virtual QMap<QString, QString> uidToResourceMap() const = 0;
+ virtual TQMap<TQString, TQString> uidToResourceMap() const = 0;
/**
* If this resource has subresources, return a QStringList of them.
* In most cases, resources do not have subresources, so this is
* by default just empty.
*/
- virtual QStringList subresources() const { return QStringList(); }
+ virtual TQStringList subresources() const { return TQStringList(); }
/**
* Is this subresource active or not?
*/
- virtual bool subresourceActive( const QString& ) const { return true; }
+ virtual bool subresourceActive( const TQString& ) const { return true; }
/**
* Is the given subresource writable?
*/
- virtual bool subresourceWritable( const QString& ) const = 0;
+ virtual bool subresourceWritable( const TQString& ) const = 0;
/**
* Completion weight for a given subresource
*/
- virtual int subresourceCompletionWeight( const QString& ) const = 0;
+ virtual int subresourceCompletionWeight( const TQString& ) const = 0;
/**
* Label for a given subresource
*/
- virtual QString subresourceLabel( const QString& ) const = 0;
+ virtual TQString subresourceLabel( const TQString& ) const = 0;
public slots:
/**
* (De-)activate a subresource.
*/
- virtual void setSubresourceActive( const QString &, bool active ) = 0;
+ virtual void setSubresourceActive( const TQString &, bool active ) = 0;
/**
* Set completion weight for a given subresource
*/
- virtual void setSubresourceCompletionWeight( const QString&, int weight ) = 0;
+ virtual void setSubresourceCompletionWeight( const TQString&, int weight ) = 0;
signals:
/**
* This signal is emitted when a subresource is added.
*/
- void signalSubresourceAdded( KPIM::ResourceABC *, const QString &type,
- const QString &subResource );
+ void signalSubresourceAdded( KPIM::ResourceABC *, const TQString &type,
+ const TQString &subResource );
/**
* This signal is emitted when a subresource is removed.
*/
- void signalSubresourceRemoved( KPIM::ResourceABC *, const QString &type,
- const QString &subResource );
+ void signalSubresourceRemoved( KPIM::ResourceABC *, const TQString &type,
+ const TQString &subResource );
};
@@ -55,58 +55,58 @@ public:
/**
- * If this resource has subresources, return a QStringList of them.
+ * If this resource has subresources, return a TQStringList of them.
* In most cases, resources do not have subresources, so this is
* by default just empty.